==> insuideindoor-1.0.4%2B1.tar.gz: lib/response/poi_response.dart <==
class POI_Response {
  bool success;
  List<PoiDataResponse> poidataresponseList;


  POI_Response({required this.success, required this.poidataresponseList});
  factory POI_Response.fromJson(Map<String, dynamic> parsedJson) {
    var listDataFromJson = parsedJson['data'] as List;
    List<PoiDataResponse> poidataList =
        listDataFromJson.map((i) => PoiDataResponse.fromJson(i)).toList();
    return POI_Response(
        success: parsedJson['success'], poidataresponseList: poidataList);
  }
}

class LocationsResponse {
  double latitude;
  double longitude;

  LocationsResponse(this.latitude, this.longitude);

  factory LocationsResponse.fromJson(Map<String, dynamic> parsedJson){
    return LocationsResponse(parsedJson['lat'], parsedJson['lng']);
  }

}

class PoiDataResponse {
  String id;
  PoiMultilingual poiMultilingual;
  List<LocationsResponse> locationResponseList;

  PoiDataResponse(
      {required this.id,
      required this.poiMultilingual,
      required this.locationResponseList});

  factory PoiDataResponse.fromJson(Map<String, dynamic> parsedJson) {
    var listLocationDataFromJson = parsedJson['locations'] as List;
    List<LocationsResponse> locationdataList = listLocationDataFromJson
        .map((i) => LocationsResponse.fromJson(i))
        .toList();
    return PoiDataResponse(
        id: parsedJson['_id'],
        poiMultilingual: PoiMultilingual.fromJson(
          parsedJson['poi_multilingual'],
        ),
        locationResponseList: locationdataList);
  }
}

class PoiMultilingual {
  En en;

  PoiMultilingual({required this.en});

  factory PoiMultilingual.fromJson(Map<String, dynamic> parsedJson) {
    return PoiMultilingual(en: En.fromJson(parsedJson['en']));
  }
}

class En {
  String name;
  String description;

  En({required this.name, required this.description});

  factory En.fromJson(Map<String, dynamic> parsedJson) {
    return En(name: parsedJson['name'], description: parsedJson['description']);
  }
}

==> insuideindoor-1.0.5%2B1.tar.gz: lib/response/poi_response.dart <==
class POI_Response {
  bool success;
  List<PoiDataResponse> poidataresponseList;


  POI_Response({required this.success, required this.poidataresponseList});
  factory POI_Response.fromJson(Map<String, dynamic> parsedJson) {
    var listDataFromJson = parsedJson['data'] as List;
    List<PoiDataResponse> poidataList =
        listDataFromJson.map((i) => PoiDataResponse.fromJson(i)).toList();
    return POI_Response(
        success: parsedJson['success'], poidataresponseList: poidataList);
  }
}

class LocationsResponse {
  double latitude;
  double longitude;
  String banner_url;
  String terminal;

  LocationsResponse(this.latitude, this.longitude,this.banner_url,this.terminal);

  factory LocationsResponse.fromJson(Map<String, dynamic> parsedJson){
    return LocationsResponse(parsedJson['lat'], parsedJson['lng'],parsedJson['banner_url'],parsedJson['terminal']);
  }

}

class PoiDataResponse {
  String id;
  String category;
  String description;
  String logo_url;
  PoiMultilingual poiMultilingual;
  List<LocationsResponse> locationResponseList;
  String subcategory;

  PoiDataResponse(
      {required this.id,
        required this.category,
        required this.description,
        required this.logo_url,
      required this.poiMultilingual,
        required this.subcategory,
      required this.locationResponseList});

  factory PoiDataResponse.fromJson(Map<String, dynamic> parsedJson) {
    var listLocationDataFromJson = parsedJson['locations'] as List;
    List<LocationsResponse> locationdataList = listLocationDataFromJson
        .map((i) => LocationsResponse.fromJson(i))
        .toList();
    return PoiDataResponse(
        id: parsedJson['_id'],
        category: parsedJson['category'],
        description: parsedJson['description'],
        logo_url: parsedJson['logo_url'],
        poiMultilingual: PoiMultilingual.fromJson(
          parsedJson['poi_multilingual'],
        ),
        subcategory: parsedJson['subcategory'],
        locationResponseList: locationdataList);
  }
}

class PoiMultilingual {
  En en;

  PoiMultilingual({required this.en});

  factory PoiMultilingual.fromJson(Map<String, dynamic> parsedJson) {
    return PoiMultilingual(en: En.fromJson(parsedJson['en']));
  }
}

class En {
  String name;
  String description;

  En({required this.name, required this.description});

  factory En.fromJson(Map<String, dynamic> parsedJson) {
    return En(name: parsedJson['name'], description: parsedJson['description']);
  }
}
